@@ -24,6 +24,7 @@ if __name__ == '__main__':
     device_file = os.path.join(script_dir, os.pardir, "um7_A500CNP8.json")
     um7 = UM7Serial(device=device_file)
 
-    for packet in um7.recv_broadcast(num_packets=1000):
+    flush_on_start = True  # <-- optional, set to true if you want to reset input buffer when starting reception
+    for packet in um7.recv_broadcast(num_packets=1000, flush_buffer_on_start=flush_on_start):
         logging.warning(packet)
 
